/***********************************************************************/
/* Open Visualization Data Explorer                                    */
/* (C) Copyright IBM Corp. 1989,1999                                   */
/* ALL RIGHTS RESERVED                                                 */
/* This code licensed under the                                        */
/*    "IBM PUBLIC LICENSE - Open Visualization Data Explorer"          */
/***********************************************************************/
#define NDDL2DPTS 2 
#define NDDL2DLNS 1 

#include <dxconfig.h>


static Point points[NDDL2DPTS] = {
 {  0.0000000000F,      0.0000000000F,  0.0F },
 {  0.0000000000F,      1.0000000000F,  0.0F },
};
   
static Line lines[NDDL2DLNS] = {
  {  0,   1 }
};

